[llvm] [CodeLayout] Changed option names cds to cdsort (PR #69668)

via llvm-commits llvm-commits at lists.llvm.org
Thu Oct 19 17:58:32 PDT 2023


https://github.com/spupyrev created https://github.com/llvm/llvm-project/pull/69668

None

>From 3f38c2ba96724673d884d3312d92f5b76386fb2f Mon Sep 17 00:00:00 2001
From: spupyrev <spupyrev at fb.com>
Date: Thu, 19 Oct 2023 17:57:43 -0700
Subject: [PATCH] [CodeLayout] Changed option names cds to cdsort

---
 llvm/lib/Transforms/Utils/CodeLayout.cpp | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/llvm/lib/Transforms/Utils/CodeLayout.cpp b/llvm/lib/Transforms/Utils/CodeLayout.cpp
index 6252c429205ab62..20015ab01a0c5dd 100644
--- a/llvm/lib/Transforms/Utils/CodeLayout.cpp
+++ b/llvm/lib/Transforms/Utils/CodeLayout.cpp
@@ -116,19 +116,19 @@ static cl::opt<bool> EnableChainSplitAlongJumps(
     "ext-tsp-enable-chain-split-along-jumps", cl::ReallyHidden, cl::init(true),
     cl::desc("The maximum size of a chain to apply splitting"));
 
-// Algorithm-specific options for CDS.
-static cl::opt<unsigned> CacheEntries("cds-cache-entries", cl::ReallyHidden,
+// Algorithm-specific options for CDSort.
+static cl::opt<unsigned> CacheEntries("cdsort-cache-entries", cl::ReallyHidden,
                                       cl::desc("The size of the cache"));
 
-static cl::opt<unsigned> CacheSize("cds-cache-size", cl::ReallyHidden,
+static cl::opt<unsigned> CacheSize("cdsort-cache-size", cl::ReallyHidden,
                                    cl::desc("The size of a line in the cache"));
 
 static cl::opt<double> DistancePower(
-    "cds-distance-power", cl::ReallyHidden,
+    "cdsort-distance-power", cl::ReallyHidden,
     cl::desc("The power exponent for the distance-based locality"));
 
 static cl::opt<double> FrequencyScale(
-    "cds-frequency-scale", cl::ReallyHidden,
+    "cdsort-frequency-scale", cl::ReallyHidden,
     cl::desc("The scale factor for the frequency-based locality"));
 
 namespace {
@@ -1009,8 +1009,8 @@ class ExtTSPImpl {
   std::vector<ChainT *> HotChains;
 };
 
 /// The implementation of the Cache-Directed Sort (CDS) algorithm for ordering
 /// functions represented by a call graph.
 class CDSortImpl {
 public:
   CDSortImpl(const CDSortConfig &Config, ArrayRef<uint64_t> NodeSizes,
@@ -1009,8 +1009,8 @@ class ExtTSPImpl {
 };
 
-/// The implementation of the Cache-Directed Sort (CDS) algorithm for ordering
-/// functions represented by a call graph.
+/// The implementation of the Cache-Directed Sort (CDSort) algorithm for
+/// ordering functions represented by a call graph.
 class CDSortImpl {
 public:



More information about the llvm-commits mailing list